
/* Policy Coalition Building in an Authoritarian Legislature: Evidence from Chinas National Assemblies (1983C2007) */
/* Xiaobo Lu, Mingxing Liu and Feiyue Li                                   */
/* This file replicates the empirical analysis in the main text and appendix  */
/* May 2018                                                     */




/*********************************************************************/
/* Figure 2: Policy Coalition in the NPC (1983 C 2007)               */
/*********************************************************************/

/* Narrow Definition of NPC Coalition */
/* NPC Coalition   */
use "NPC_TSCS.dta", clear

egen coalition_id=group(year proposal_title)
tab coalition_id, gen(coalition_year)

collapse (count) time (sum) cosponsor coalition_year* (mean) npc_num_proposal_compul  workunit_central eduexp female npc_exp party2dmy1 party2dmy2 party2dmy3, by(proposal_title year)
sort year
/* Num. of Province in a coalition */
gen co_sign_prov1=time if time>1
/* Num. of delegates in a coalition */
gen co_sign_delegate1=cosponsor if time>1
/* Num. of coalitions */
gen coalition1=1 if time>1
replace coalition1=0 if time==1
/* Percentage of coalitions */
by year: egen npc_proposal_sum1=count(year)
by year: egen co_sign1=count(year) if time>1 
gen pct_co_sign1=co_sign1/npc_proposal_sum1*100 

rename time proposal_per_prov1
rename cosponsor proposal_per_delegate1

save "NPC_TSCS_co_sign1_compul_10.dta",replace

collapse (sum) coalition1 co_sign_prov1 co_sign_delegate1 coalition_year* (mean) pct_co_sign1 proposal_per_prov1 proposal_per_delegate1,by(year)
sort year
mvencode _all, mv(0) override

/* Change coalition_year = 0 if coalition year ==1 for the bar chart*/
local i = 1
while `i'<=140 {
				replace coalition_year`i'=0 if coalition_year`i'==1
				local i=`i'+1
				}


/* Panel A */
scatter proposal_per_prov1 year, msymbol(O) mcolor(black) ||  scatter co_sign_prov1 year, xline(1986 1993 1995 2006, lpattern(dash)) yline(1) msymbol(Sh) mcolor(blue)  xlabel(1983(1)2007, labsize(tiny) ) title("Province Participation in Policy Coalition in NPC (Narrow Definition)") ytitle("Number of Provinces") xtitle("Year") legend(label(1 "Province Per Bill") label(2 "Frequency of Prov. Participation")) graphregion(fcolor(white))

/* Panel C */
scatter proposal_per_delegate1 year, msymbol(O) mcolor(black) ||  scatter co_sign_delegate1 year, xline(1986 1993 1995 2006, lpattern(dash)) yline(30) msymbol(Sh) mcolor(blue) xlabel(1983(1)2007, labsize(tiny))  title("Deputy Participation in Policy Coalition in NPC (Narrow Definition)")  ytitle("Number of NPC Deputies") xtitle("Year") legend(label(1 "Delegate Per Bill") label(2 "Frequency of Deputy Participation")) graphregion(fcolor(white))




/* Broad Definition of NPC Coalition */
use "NPC_TSCS.dta", clear


egen coalition_id=group(year proposal_title2)
tab coalition_id, gen(coalition_year)


collapse (count) time (sum) cosponsor coalition_year* (mean) npc_num_proposal_compul workunit_central eduexp female npc_exp party2dmy1 party2dmy2 party2dmy3, by(proposal_title2 year)
sort year
/* Num. of Province in a coalition */
gen co_sign_prov2=time if time>1
/* Num. of delegates in a coalition */
gen co_sign_delegate2=cosponsor if time>1
/* Num. of coalitions */
gen coalition2=1 if time>1
replace coalition2=0 if time==1
/* Percentage of coalitions */
by year: egen npc_proposal_sum2=count(year)
by year: egen co_sign2=count(year) if time>1 
gen pct_co_sign2=co_sign2/npc_proposal_sum2*100 


rename time proposal_per_prov2
rename cosponsor proposal_per_delegate2

save "NPC_TSCS_co_sign2_compul_10.dta",replace


collapse (sum) coalition2 co_sign_prov2 co_sign_delegate2 coalition_year* (mean) npc_proposal_sum2 co_sign2 pct_co_sign2 proposal_per_prov2 proposal_per_delegate2,by(year)
sort year
mvencode _all, mv(0) override


/* Change coalition_year = 0 if coalition year ==1 for the bar chart*/
local i = 1
while `i'<=72 {
				replace coalition_year`i'=0 if coalition_year`i'==1
				local i=`i'+1
				}
				
/* Panel B */
scatter proposal_per_prov2 year, msymbol(O) mcolor(black) ||  scatter co_sign_prov2 year, xline(1986 1993 1995 2006, lpattern(dash)) yline(1) msymbol(Sh) mcolor(blue) xlabel(1983(1)2007, labsize(tiny) ) title("Province Participation in Policy Coalition in NPC (Broad Definition)") ytitle("Number of Provinces") xtitle("Year") legend(label(1 "Province Per Bill") label(2 "Frequency of Prov. Participation")) graphregion(fcolor(white))

/* Panel D */
scatter proposal_per_delegate2 year, msymbol(O) mcolor(black) ||  scatter co_sign_delegate2 year, xline(1986 1993 1995 2006, lpattern(dash)) yline(30) msymbol(Sh) mcolor(blue) xlabel(1983(1)2007, labsize(tiny))  title("Deputy Participation in Policy Coalition in NPC  (Broad Definition)")  ytitle("Number of NPC Deputies") xtitle("Year") legend(label(1 "Deputy Per Bill") label(2 "Frequency of Deputy Participation")) graphregion(fcolor(white))


/*********************************************************/
/* Figure 3: Policy Coalition in the CPPCC (1983 C 2007) */
/*********************************************************/

/* CPPCC Coalition       */

use "CPPCC_TSCS.dta",clear


/* Total number of delegate */
sort year
by year: egen cppcc_co_sign_delegate=sum(cosponsor) if cosponsor>1

/* Num. of propoposal in the demand central finance coalition*/
by year: egen num_dcf=sum(Demand_Ctl_Finance)

/* Num. of delegates in the demand central finance coalition */
by year: egen num_delegate_dcf=sum(cosponsor) if National_Pol==1

/* Num. of propoposal in the national policy coalition*/
by year: egen num_np=sum(National_Pol)

/* Num. of delegates in the national policy coalition */
by year: egen num_delegate_np=sum(cosponsor) if National_Pol==1



collapse cosponsor cppcc_co_sign_delegate num_dcf num_delegate_dcf num_np  num_delegate_np (count) prov_id,by(year)
rename prov_id cppcc_proposal_sum
rename cosponsor proposal_per_delegate_cppcc
sort year
mvencode _all, mv(0) override

drop if year==0


scatter num_np year, msymbol(O) mcolor(black) yaxis(1) yscale(range(0) axis(1)) ytitle("Number of Proposals", axis(1)) ||  scatter num_delegate_np year, ytitle("Frequency of  Delegates", axis(2)) msymbol(Sh) mcolor(blue) yaxis(2) yscale(range(0) axis(2)) xlabel(1983(1)2007, labsize(tiny) ) title("The Coalition of National Policy")  xtitle("Year") legend(label(1 "Num. of Proposals") label(2 "Frequency of Delegates")) xline(1986 1993 1995 2006, lpattern(dash)) graphregion(fcolor(white))


scatter num_dcf year, msymbol(O) mcolor(black) yaxis(1) yscale(range(0) axis(1)) ytitle("Number of Proposals", axis(1)) ||  scatter num_delegate_dcf year, ytitle("Frequency of  Delegates", axis(2)) msymbol(Sh) mcolor(blue) yaxis(2) yscale(range(0) axis(2)) xlabel(1983(1)2007, labsize(tiny) ) title("The Coalition of Demand Central Finance")  xtitle("Year") legend(label(1 "Num. of Proposals") label(2 "Num. of Delegates")) xline(1986 1993 1995 2006, lpattern(dash)) graphregion(fcolor(white))





/**********************************************************/
/* Figure 4: The Education Tie of Delegates (1983 C 2007) */
/**********************************************************/


/* NPC Data */
use "NPC_TSCS.dta",clear
keep year eduexp
rename eduexp eduexp_all
sort year
save "NPC_TSCS_all_compul_10_eduexp.dta", replace

use "NPC_TSCS_co_sign1_compul_10.dta",clear
keep year eduexp
rename eduexp eduexp_sign1
sort year
save "NPC_TSCS_co_sign1_compul_10_eduexp.dta", replace

use "NPC_TSCS_co_sign2_compul_10.dta",clear
keep year eduexp
rename eduexp eduexp_sign2
sort year
save "NPC_TSCS_co_sign2_compul_10_eduexp.dta", replace

merge year using "NPC_TSCS_co_sign1_compul_10_eduexp.dta"
sort year
drop _merge 
merge year using "NPC_TSCS_all_compul_10_eduexp.dta"


graph bar (mean) eduexp_all eduexp_sign1 eduexp_sign2, over(year,label(labsize(tiny))) bargap(-30) legend(label(1 "All NPC Bill") label(2 "Coalition (Narrow)") label(3 "Coalition (Broad)") cols(1)) title("NPC Bills") ytitle("% of Delegate with Education Tie") bar(1,color(black) fcolor(white)) bar(2,color(edkblue)) bar(3,color(eltblue))  graphregion(fcolor(white)) 
			 
			

/* CPPCC Data */
/* Percent of proposal coming from CPPCC representative has education related background */
use "CPPCC_TSCS.dta",clear

/* Generate the education background variable of interests */
gen eduexp_np=eduexp if National_Pol==1
gen eduexp_dcf=eduexp if Demand_Ctl_Finance==1

* Generate graphs */
/* The change of delegate characteristics over time */
graph bar (mean) eduexp eduexp_np eduexp_dcf, over(year,label(labsize(tiny))) bargap(-30) legend(label(1 "All CPPCC Proposal") label(2 "National Policy Coalition") label(3 "Demand Central Gov. Funding Coalition") cols(1)) title("CPPCC Proposals") ytitle("% of Delegate with Education Tie") bar(1,color(black) fcolor(white)) bar(2,color(edkblue)) bar(3,color(eltblue)) graphregion(fcolor(white)) 
			 

/*************************************************************************************************/			 
/* Table 1: The Characteristics of NPC Bill & CPPCC Proposal on Compulsory Education (1983-2007) */
/*************************************************************************************************/

use "NPC_TSCS.dta", clear 
sum workunit_central eduexp female_npc npc_exp party2dmy1 party2dmy2 party2dmy3

use "CPPCC_TSCS.dta", clear 
sum workunit_central eduexp female cppcc_exp party2dmy1 party2dmy2 party2dmy3
 

/* Table 2: Network Analysis of Policy Coalition  */
/* See the R file for reported centrality analysis*/ 


/************************************************************************/			 
/* Table A1: Determinants of Policy Coalition Participation (1983-2007) */
/************************************************************************/			 


/* NPC data */
use "NPC_TSCS.dta", clear


/* Coalition formation */
probit coalition1 workunit_central eduexp female_npc npc_exp party2dmy2 party2dmy3, cluster(year)

probit coalition1 workunit_central eduexp centrl_edu female_npc npc_exp party2dmy2 party2dmy3, cluster(year)

probit coalition2 workunit_central eduexp female_npc npc_exp party2dmy2 party2dmy3, cluster(year)

probit coalition2 workunit_central eduexp centrl_edu female_npc npc_exp party2dmy2 party2dmy3, cluster(year)




/* CPPCC */

use "CPPCC_TSCS.dta", clear
sort year

probit  National_Pol workunit_central eduexp female cppcc_exp party2dmy2 party2dmy3, cluster(year)

probit  National_Pol workunit_central eduexp centrl_edu female cppcc_exp party2dmy2 party2dmy3, cluster(year)

probit   Demand_Ctl_Finance workunit_central eduexp female cppcc_exp party2dmy2 party2dmy3, cluster(year)

probit   Demand_Ctl_Finance workunit_central eduexp centrl_edu female cppcc_exp party2dmy2 party2dmy3*, cluster(year)



/***********************************************************/
/* Figure B1: Evaluating Constituency Influence in the NPC */
/***********************************************************/
use "CPPCC_NPC_Proposal_by_province.dta", clear

graph twoway (lfit npc_proposal_compul survey2004) (scatter npc_proposal_compul survey2004,  mlabel(prov_eng) mcolor(blue) msize(small)  mlabsize(tiny)  mlabcolor(black)), by(year,legend(off) graphregion(fcolor(white))) ytitle(Number of NPC Bills) xtitle(Gov. Should Shoulder Greater Financial Burden for Compulsory Edu. (2004)) xlabel(2 3 4 5)

/*************************************************************/
/* Figure B2: Evaluating Constituency Influence in the CPPCC */
/*************************************************************/
graph twoway (lfit cppcc_num_proposal survey2004) (scatter cppcc_num_proposal survey2004,  mlabel(prov_eng) mcolor(blue) msize(small)  mlabsize(tiny)  mlabcolor(black)), by(year,legend(off) graphregion(fcolor(white))) ytitle(Number of CPPCC Proposals) xtitle(Gov. Should Shoulder Greater Financial Burden for Compulsory Edu.(2004)) xlabel(2 3 4 5)

