
# This is replication file for newtwork construction and analysis----------------------
# 
# software
# 
#  R version 3.4.2 




# packages required----------------------------------------------------
# 

library(magrittr)
library(dplyr)
library(tidyr)
library(igraph)
library(haven)
library(foreign)



setwd("C:\\Users\\xl5484.AUSTIN\\Box Sync\\Research_Shared\\China_Edu_Consult_Con\\Data\\Replication_Files\\CPS_Replication_Files")




# Read in data----------------------------------------------------------
# rm(list = ls())

cpp<-read_dta("cppraw.dta") %>%
  select(type,person,party,year, workunit_central, 
         prov_eng, National_Pol, Demand_Ctl_Finance, 
         minority_proposal, edusys_current, edusys_past,
         female, cppcc_exp,minority_proposal)%>%
  arrange(person,year) %>%
  # generate an index, for no index for each proposal in the original data set
  mutate(index=row_number())  



# Keep individual proposers------------------------------------------------
cppind<-
  cpp %>%filter(grepl("[0-9]",person))%>%
  separate(person, into=c("name","others"),sep="?")%>%  # adjust something like "姚代亮?3人"
  rename(person=name)%>%
  select(-others)%>%
  bind_rows(.,cpp%>%filter(!grepl("[0-9]",person)))%>%
  filter(type %in% c("","个人提案","个人联名"))%>%  # delete "党派提案"
  mutate(person=gsub("·|[[:blank:]]","",person))%>% # delete "·" and blank in the name
  rename(name=person)%>% 
  arrange(name,year,index)%>%
  group_by(name,year)%>%                # sum up the subject of proposals for each legislator in each year.
  mutate(psseq=row_number(),psnum=n())%>%
  mutate_at(vars(National_Pol,Demand_Ctl_Finance,minority_proposal),funs(sum(.))) %>% 
  mutate_at(vars(National_Pol,Demand_Ctl_Finance,minority_proposal),funs(.>0)) %>%   # whether at least one of his proposal is of certain type.
  select(-index)%>%
  distinct(name,year,.keep_all=T) %>%  # unique observation for each legislator in each year
  ungroup %>%
  within(.,id<-match(name, unique(name)))%>%
  select(id,name,year,psnum,everything(),-psseq)

## Vertex attributes------------------------------------------------------

cppver<-cppind%>%
  rename(namecn=name,name=id)%>%
  mutate(edu=(edusys_current==1|edusys_past==1),
         bgd=ifelse(edu==1 & workunit_central==1,1,
                    ifelse(edu==0 & workunit_central==1,2,
                           ifelse(edu==1 & workunit_central==0, 3,
                                  ifelse(edu==0 & workunit_central==0,4,NA)))))


# Edge attributes ---------------------------------------------------------

cppedg<- cppind %>%
  select(id,year)%>%
  mutate(ego=id,alter=id)%>%
  select(-id)%>%
  group_by(year)%>%
  complete(ego,alter) %>%  # create complete edge list for each year
  ungroup %>% 
  full_join(.,cppind,by=c("ego"="id","year"="year")) %>%
  full_join(.,cppind,by=c("alter"="id","year"="year"))%>%
  set_names(names(.)%>%gsub("\\.x","_ego",.)%>%gsub("\\.y","_alter",.)) %>%
  mutate(party=(party_ego==party_alter & !(party_ego %in% c(0,10))),
         party=replace(party,is.na(party),F),
         prov=(prov_eng_ego==prov_eng_alter),
         nation=(National_Pol_ego & National_Pol_alter),
         finance=(Demand_Ctl_Finance_ego &Demand_Ctl_Finance_alter),
         ccp=(party==1 & party_ego==8),
         ccp=replace(ccp,is.na(ccp),F)
  ) %>%
  select(year,ego,alter,party,prov,nation,finance, ccp,
         contains("party"),contains('prov_eng'),contains("National"),
         contains('Finance')) %>%
  select(year,ego,alter,party,prov,nation,finance,ccp)



# #

# Network construction ----------------------------------------------------


# function for network construction
crnet <- function(edg,ver) {
  net<-edg %>%
    filter(party|prov|nation|finance)%>%
    graph_from_data_frame(directed = F, vertices=ver) %>%
    as.undirected("collapse") %>%
    simplify(edge.attr.comb="max")
  return(net)
}


yr<-1983:2007

netname<-paste("cppg",yr,sep="_")

for (i in 1:length(yr)) {
  net<-crnet(cppedg%>%filter(year==yr[i])%>%select(-year),cppver%>%filter(year==yr[i]));
  assign(netname[i],net)
}


#  the full network
cppgyr<-mget(netname)




#  network of "Nantial_Pol"
cppgyr_NP<-cppgyr %>%
  lapply(.,function(x){
    x %>%
      induced_subgraph(.,
                       x %>% 
                         igraph::as_data_frame("vertices") %>%
                         filter(National_Pol==1)%>%
                         select(name)%>%
                         extract2(1)
      ) %>%
      subgraph.edges(., E(.)[prov==1|party==1],delete.vertices=F)
  })


#  network of "Demand_Ctl_Finance"

cppgyr_DF<-cppgyr %>%
  lapply(.,function(x){
    x %>%
      induced_subgraph(.,
                       x %>% 
                         igraph::as_data_frame("vertices") %>%
                         filter(Demand_Ctl_Finance==1)%>%
                         select(name)%>%
                         extract2(1)
      ) %>%
      subgraph.edges(., E(.)[prov==1|party==1],delete.vertices=F)
  })



# Centraity scores-----------------------------------------------------


#  network of "Nantial_Pol"
cppcen_NP<-cppgyr_NP %>%
  lapply(function(x){
    bet<-betweenness(x,normalized = T)
    eig<-evcent(x)%>%use_series(vector)
    name<-V(x)$name %>% as.character %>% as.numeric
    year<-V(x)$year
    return(data.frame(year,name,bet,eig))
  }) %>%
  do.call(bind_rows,.) %>%
  left_join(.,cppver) %>%
  arrange(year,name)


#  network of "Demand_Ctl_Finance"
cppcen_DF<-cppgyr_DF %>%
  lapply(function(x){
    bet<-betweenness(x,normalized = T)
    eig<-evcent(x)%>%use_series(vector)
    name<-V(x)$name %>% as.character %>% as.numeric
    year<-V(x)$year
    return(data.frame(year,name,bet,eig))
  }) %>%
  do.call(bind_rows,.) %>%
  left_join(.,cppver) %>%
  arrange(year,name)


#  Brokerage------------------------------------------------------
#  
library(network)
library(sna)
library(intergraph)


#  network of "Nantial_Pol"
cppbrk_NP <- cppgyr_NP %>%
  .[cppgyr_NP%>% sapply(function(x)gorder(x)) %>% is_greater_than(0)%>%which()%>% as.vector()] %>%
  lapply(function(x) {
    name<-V(x)$name %>% as.character %>% as.numeric
    year<-V(x)$year
    cl<- x %>% 
      igraph::as_data_frame("vertices")%>%
      select(name,party) %>% 
      mutate(party2=replace(party,party==0|party==10|is.na(party),11)) %>% 
      group_by(party2) %>% 
      mutate(cl=replace(party2,party2==11,11+row_number())) %>% 
      ungroup %>%
      select(cl)%>%
      extract2(1)
    brk <- brokerage(asNetwork(x),cl) %>%
      magrittr:: extract(1:4) %>%
      set_names(c("raw","exp","sd","z")) %>%
      data.frame()
    return(data.frame(year,name,brk))
  }) %>%
  do.call(bind_rows,.) %>%
  left_join(.,cppver) %>%
  arrange(year,name)


#  network of "Demand_Ctl_Finance"
cppbrk_DF <- 
  cppgyr_DF %>%
  .[cppgyr_DF %>% sapply(function(x)gorder(x)) %>% is_greater_than(0)%>%which()%>% as.vector()] %>%
  lapply(function(x) {
    name<-V(x)$name %>% as.character %>% as.numeric
    year<-V(x)$year
    cl<- x %>% 
      igraph::as_data_frame("vertices")%>%
      select(name,party) %>% 
      mutate(party2=replace(party,party==0|party==10|is.na(party),11)) %>% 
      group_by(party2) %>% 
      mutate(cl=replace(party2,party2==11,11+row_number())) %>% 
      ungroup %>%
      select(cl)%>%
      extract2(1)
    brk <- brokerage(asNetwork(x),cl) %>%
      magrittr:: extract(1:4) %>%
      set_names(c("raw","exp","sd","z")) %>%
      data.frame()
    return(data.frame(year,name,brk))
  }) %>%
  do.call(bind_rows,.) %>%
  left_join(.,cppver) %>%
  arrange(year,name)


detach('package:sna')
detach('package:network')
detach('package:intergraph')


# combine centrality scores and  brokerage index
NP <- cppbrk_NP %>% 
  select(year,name,z.t,bgd) %>% 
  left_join(cppcen_NP %>% select(year,name,eig,bet)) %>% 
  mutate(MOE=(bgd==1)+0)



DF <- cppbrk_DF %>% 
  select(year,name,z.t,bgd) %>% 
  left_join(cppcen_DF %>% select(year,name,eig,bet)) %>% 
  mutate(MOE=(bgd==1)+0)


# Table 2: Network Analysis of Policy Coalition------------------------
# 
#  network of "Nantial_Pol"
#  

NP %>% 
  filter(!is.na(MOE)) %>% 
  group_by(MOE) %>% 
  summarize_at(vars(bet,eig,z.t),funs(n()))



NP %>% 
  filter(!is.na(MOE)) %$% 
  t.test(bet~MOE) 


NP %>% 
  filter(!is.na(MOE)) %$% 
  t.test(eig~MOE)


NP %>% 
  filter(!is.na(MOE)) %$% 
  t.test(z.t~MOE)



#  network of Demand_Ctl_Finance"
#  

DF %>% 
  filter(!is.na(MOE)) %>% 
  group_by(MOE) %>% 
  summarize_at(vars(bet,eig,z.t),funs(sum(!is.na(.))))



DF %>% 
  filter(!is.na(MOE)) %$% 
  t.test(bet~MOE) 


DF %>% 
  filter(!is.na(MOE)) %$% 
  t.test(eig~MOE)


DF %>% 
  filter(!is.na(MOE)) %$% 
  t.test(z.t~MOE)




# Network Plot ------------------------------------------------------------


yr<-1983:2007
netname<-cppgyr %>% names
n<-length(netname)

for (i in 1:n) {
  net<-cppgyr[[netname[i]]]
  
  netDF<-net %>%
    induced_subgraph(.,
                     net %>% 
                       igraph::as_data_frame("vertices") %>%
                       filter(Demand_Ctl_Finance==1)%>%
                       select(name)%>%
                       extract2(1)
    ) %>%
    subgraph.edges(., E(.)[prov==1|party==1],delete.vertices=F)
  assign(paste(netname[i],"_DF",sep=""),netDF)
  
  netNP<-net %>%
    induced_subgraph(.,
                     net %>% 
                       igraph::as_data_frame("vertices") %>%
                       filter(National_Pol==1)%>%
                       select(name)%>%
                       extract2(1)
    ) %>%
    subgraph.edges(., E(.)[prov==1|party==1],delete.vertices=F)
  assign(paste(netname[i],"_NP",sep=""),netNP)
  
  
  pdf(file=paste("cppg_yr_text",yr[i],"_NPDF",".pdf",sep=""), width = 14, height = 9)
  
  par(mfrow=c(1,2))
  
  set.seed(100)
  lNP<-netNP%>%layout_with_kk
  netNP %>%
    plot(., layout=lNP,
         vertex.size=5,
         vertex.label=NA,
         vertex.color=c("gray60","black")[is.element(V(.)$bgd,c(1,2))+1],
         vertex.shape=c("circle","square")[is.element(V(.)$bgd,c(1,3))+1],
         edge.width=. %>%
           as_data_frame %>% 
           select(prov,party)%>%
           with(.,ifelse(party==1&prov==1,5,1)),
         edge.lty=. %>%
           as_data_frame %>% 
           select(prov,party)%>%
           with(.,ifelse(party==1&prov!=1,2,1)),
         edge.color=. %>%
           as_data_frame %>% 
           select(prov,party,ccp)%>%
           with(.,ifelse((party==1&prov==1)|(party==1&ccp==1),"black","gray80")))
  title(sub="Coalition of National Policy",cex.sub=1.2)
  
  if (vcount(netDF)>0) {
    set.seed(100)
    lDF<-netDF%>%layout_with_kk
    netDF %>%
      plot(., layout=lDF,
           vertex.size=5,
           vertex.label=NA,
           vertex.color=c("gray60","black")[is.element(V(.)$bgd,c(1,2))+1],
           vertex.shape=c("circle","square")[is.element(V(.)$bgd,c(1,3))+1],
           edge.width=. %>%
             as_data_frame %>% 
             select(prov,party)%>%
             with(.,ifelse(party==1&prov==1,5,1)),
           edge.lty=. %>%
             as_data_frame %>% 
             select(prov,party)%>%
             with(.,ifelse(party==1&prov!=1,2,1)),
           edge.color=. %>%
             as_data_frame %>% 
             select(prov,party,ccp)%>%
             with(.,ifelse((party==1&prov==1)|(party==1&ccp==1),"black","gray80")))
    title(sub="Coalition of Demand Central Gov. Financial Resource",cex.sub=1.2)
  } else {
    make_ring(1) %>% 
      plot(vertex.label=NA, vertex.color="white", 
           edge.color=NA,mark.border=NA,vertex.size=0)
    title(sub="Coalition of Demand Central Gov. Financial Resource",cex.sub=1.2)
  }
  
  
  par(xpd=NA)
  legend(-2.5,-1.2,
         c("Central & Edu","Central & Non-Edu","Local & Edu","Local & Non-Edu","Prov Link","Non-CCP Party Link","CCP Party Link","Party & Prov Link"),
         lty=c(-1,-1,-1,-1,1,2,2,1),lwd=c(-1,-1,-1,-1,1,1,1,5),
         pch=c(15,16,15,16,NA,NA,NA,NA),
         col=c("black","black","gray60","gray60","gray80","gray80","black","black"),
         cex=1,pt.cex=1, ncol=2
  )
  
  text( -1.5, 1.5, paste("CPPCC Policy Coalition Network ", yr[i], sep=""), font=2,cex = 1.8)
  
  
  
  dev.off()
  
} # for

